@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-from functools import partial
 from itertools import chain
 import networkx as nx
 
@@ -62,7 +61,7 @@ class NXProjector(object):
             method = kwargs.get("method", {})
             params = kwargs.get("params", [])
             return transfer(source, target, graph, method, params, attrs,
-                           node_type_attr, edge_type_attr)
+                            node_type_attr, edge_type_attr)
 
         @self.transformation_wrapper("combine")
         def execute_combine(source, target, graph, attrs, node_type_attr,
@@ -106,7 +105,7 @@ def match(node_type_seq, edge_type_seq, graph, node_type_attr="type",
 
 
 def project(source, target, graph, method="jaccard", params=[], attrs={},
-             node_type_attr="type", edge_type_attr="type", **kwargs):
+            node_type_attr="type", edge_type_attr="type", **kwargs):
     """
     Executes graph "PROJECT" projection.
 
@@ -157,7 +156,7 @@ def transfer(source, target, graph, method="edges", params=[], attrs={},
         graph = _add_edges_from(graph, edges)
     old_attrs = graph.node[target]
     merged_attrs = _merge_attrs(attrs, old_attrs,
-                                [node_type_attr])
+                                [node_type_attr, "label"])
     graph.node[target] = merged_attrs
     return graph
 
@@ -172,7 +171,7 @@ def combine(source, target, graph, node_id="", attrs={},
     :param target: Int. Target node for transformation.
     :param attrs: Dict. Attrs to be set during transformation.
     :param graph: networkx.Graph. Graph of subgraph to transform.
-    :param node_id: Int. Id for new node, will autoassign, but 
+    :param node_id: Int. Id for new node, will autoassign, but
     :returns: networkx.Graph. A projected copy of the wrapped graph
     or its subgraph.
     """
@@ -303,7 +302,7 @@ def _add_edges_from(graph, edges, edge_type_attr="type"):
         if graph.has_edge(source, target):
             edge_attrs = graph[source][target]
             merged_attrs = _merge_attrs(attrs, edge_attrs,
-                                        [edge_type_attr, "weight"])
+                                        [edge_type_attr, "weight", "label"])
             graph.adj[source][target] = merged_attrs
             graph.adj[target][source] = merged_attrs
         else:
@@ -313,25 +312,39 @@ def _add_edges_from(graph, edges, edge_type_attr="type"):
 
 def _merge_attrs(new_attrs, old_attrs, reserved=[]):
     """
-    Merges dicts handling repeated values as mulitvalued attrs using sets.
-
+    Merges attributes counting repeated attrs with dicts.
+    Kind of ugly, will need to take a look at this.
     :param new_attrs: Dict.
     :param old_attrs: Dict.
     :reserved: List. A list of attributes that cannot have more than value.
     :returns: Dict.
     """
     attrs = {}
-    attrs.update(dict(old_attrs))
+    for k, v in old_attrs.items():
+        if k in reserved:
+            attrs[k] = v
+        elif isinstance(v, dict):
+            attrs[k] = dict(v)
+        elif isinstance(v, str) or isinstance(v, unicode):
+            attrs[k] = {v: 1}
     for k, v in new_attrs.items():
         if k in reserved:
             attrs[k] = v
-        elif k not in attrs:
-            attrs[k] = set([v])
+        elif k in attrs:
+            count_dict = attrs[k]
+            if isinstance(v, dict):
+                for i, j in v.items():
+                    count_dict.setdefault(i, 0)
+                    count_dict[i] += j
+            elif isinstance(v, str) or isinstance(v, unicode):
+                count_dict.setdefault(v, 0)
+                count_dict[v] += 1
+            attrs[k] = count_dict
         else:
-            val = attrs[k]
-            if not isinstance(val, set):
-                attrs[k] = set([val])
-            attrs[k].update([v])
+            if isinstance(v, dict):
+                attrs[k] = dict(v)
+            elif isinstance(v, str) or isinstance(v, unicode):
+                attrs[k] = {v: 1}
     return attrs
 
 
